(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     35001,        748]
NotebookOptionsPosition[     32108,        697]
NotebookOutlinePosition[     32664,        718]
CellTagsIndexPosition[     32621,        715]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 8, Section 8.2, Figures 8.1\[Dash]8.3", "Section",ExpressionUUID->"ab46d1d4-c274-4c7e-aecc-dd20d81f12d5"],

Cell["\<\
We start by defining the radius as a function of semi-major axis, \
eccentricity and true anomaly.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"10b5fc25-e6ed-49be-9d0e-47c77287d93b"],

Cell["r[a_,e_,f_]:=a(1-e^2)/(1+e Cos[f]);", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"7c0deb6a-4ae7-440c-9eae-af92720ee1f0"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["ksolve", "Input"],
 " that solves Kepler's equation to find the eccentric anomaly for a given \
value of the mean anomaly and eccentricity."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"89ee7715-d7d3-4c9f-b8e7-6088cc8a6986"],

Cell["ksolve[ma_, e_] := FindRoot[ea - e Sin[ea] == ma, {ea,ma}];", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"cce93ea9-b5fb-4b3b-af06-d350e6933f7e"],

Cell[TextData[{
 "The function ",
 StyleBox["position", "Input"],
 " calculates the ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 " coordinates of an object for a particular value of the mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d7c56dea-670d-415c-af27-0b76c2e00f4b"],

Cell["\<\
position[ma_,a_,e_]:=
(eca=ea /. ksolve[ma,e];
x=N[a(Cos[eca]-e)]; y=N[a Sqrt[1-e^2] Sin[eca]];
{x,y})\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"aacec0b2-7773-468d-aba4-26a9bce8903a"],

Cell[TextData[{
 "Define the function ",
 StyleBox["Orbit", "Input"],
 " that plots an orbit of eccentricity, ",
 StyleBox["e", "Input"],
 ", with semi-major axis specified by the rational made up from the list of \
two numbers given by ",
 StyleBox["pl", "Input"],
 ".  The orbit of the outer planet is taken to be circular with unit \
semi-major axis."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e85f1368-7315-400a-8311-eca8806f31d5"],

Cell["\<\
Orbit[pl_List, e_] :=
Module[{time, p1, p2, p = Apply[Rational,pl],
        pt = If[pl[[1]] > pl[[2]], pl[[1]], pl[[2]]],
        sun=Graphics[{PointSize[0.1],Point[{0,0}]}],
        porb = Graphics[{Circle[{0,0},1]}],
        a = N[(pl[[1]]/pl[[2]])^(2/3)],
        circle = Graphics[{Circle[{0,0},1]}],
        box = 
        Graphics[Line[{{-1.1,-1.1},{1.1,-1.1},
                       {1.1,1.1},{-1.1,1.1},{-1.1,-1.1}}]]},
  ptime = Table[N[t], {t,0,pt*2*Pi,Pi/40}];
  posvec = Map[position[#,a,e]&,ptime];
  f = Map[N[ArcTan[#[[1]],#[[2]]]]&,posvec];
  rad = Map[N[Sqrt[#[[1]]^2+#[[2]]^2]]&,posvec];
  orbpts = Transpose[{rad*Cos[f],rad*Sin[f]}];
  p3 = 
  ListPlot[orbpts,
           PlotJoined->True,
           AspectRatio->Automatic, Axes->None, 
           DisplayFunction->Identity,
           PlotRange->{{-1.1,1.1},{-1.1,1.1}}];
  Show[box,sun,circle,p3,
       DisplayFunction->$DisplayFunction,
  AspectRatio->Automatic,PlotRange->All]]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"863bdfdb-6227-4c24-a780-947166430feb"],

Cell["\<\
Now plot the basic orbit for the 2:1 resonance used in Figs.8.1 and 8.2.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c8b8a9da-0de6-445b-929d-7327a24efdf3"],

Cell[CellGroupData[{

Cell["basic = Orbit[{1,2},0.5]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[5]:=",ExpressionUUID->"47377824-776b-4e38-a9f6-446ef097af73"],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
    1.1}, {-1.1, -1.1}}], 
   {PointSize[0.1], PointBox[{0, 0}]}, CircleBox[{0, 0}, 1], {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJyN1ntQVGUYBvDFSETHDEUR0cAxL7mTlSimgS8IityisfIygo4GXiIFQRlS
1EkEyxuYAuLUICAkIJqAISLzsoiahMoCgiy3XW6uICvKTSccqvme/YOTzMgM
wx9n9pzzve/z/NipG/1X+A6TyWQJ//7+9/dI4LGXibMqSIafa9v9dsamldNB
r6VlSYVXaO69+LMGVEY0rVd53/4mxfYcmX1hVCnlhD0sDbl2j0x+8bzj80Mx
dRamVl46XE7F+61KLpsXUbPTvqhTllVk817sFhfva+Shqjt+1VJFK1YmydXP
fqPjkw9pK6JrafatxBzl6HDuCvw9cW1kPZnsqavxm3eZQ3e7N40YrSaV29XK
8pPMhf0zMnYkqKnb8aMeC+Ut3mw/Ye0fIzXUt02xKTf5LrudvNTQ6aGhFybn
nMOtyniDT/y2KH8Nee/Z17vK8wFHya2i/II0ZPk072Sv90PO+dF0TYWXhlYH
99lGu9VwUVZBWvocDZkuiuy9a1bPreZNAYHtamof822W/QY1F1p8HLo6Wk3K
vnFr1MkajjUYNtFljppCFYra+upGdtAlW7f7N9AiswPt6181sVvZrK3XN9dT
y/Kg5mPvtnBOwNGLmcvqaO6X33fGjGvlPw1jLliPqaUl50e0pQ1/xCYm6+Rb
bqhoGOtULx8/4hZ31xtOvtUUuCanNTNfyx1BU+af6K2iitMDYW8deMxpdh4p
upBK+pScn05Y0Mbq+MSu2o4Kuuhw4fb4ujaOsBjuyCvLqbLhw+LpO9v5VOqz
noZsJbnHmCdt7W9njjKauNO4lF4Y7rovC37CERv+LrBNL6EeUv5kpHnCWa+8
M5vm3aHIfCuOsetg7dTxwdrLNyngOyPjoiMd3LjFZpL9+4XkPqBIT/irgxNn
xi09Y5FPm87bxSx+1cHO8dbTb6mv0Na4Vd+kWOk4RNl8b8aCDDqoDVurma/j
qoHAEIPFv1Kp/Kvgblsdm3+WKt+YcdZWcp0ln2fJ/Vn//IPi+bwD71cu3o9P
4P1rxPtzH86XIs7HkvOzZD6sn99RMT/OwHzDxXzZBvN/JObPD7CfZLEf1u9P
J/bHhthvg9gvL8X+3xH7Z0k+WIv8ZIn8sA3y5SHyxbuRPyeRPy5DPk+LfLIk
vzwF+W4S+eZ1yP9NkX+ehH5cFf1gL/QnUvSHuwb3iyX94zb001f0kyX95Wno
917Rb25G//tE/7nra+FDtPCBJ8MPT+EHZ8MXnfCFR8GfHuEPx8CnbOETfwK/
nIRfnAvf9gvfWO+fGeUZ1DokXc/DdRf4txCfnwz/9PfPh3+WeH7bG/qXCP8i
4N/62+L8L+CfscS/25ifAv6pMF8f+FeF+bsO4d8qiX/jsN/cIfwbJfGvE/kp
gH/3ka8z8E+Sv//5V4P8FsA/W+Q7H/45Iv9j4d/b6Ica/gWgP8+H8G8h+qeB
f5J+Uhn6G/+G/nXBB4XEv2r4p/fl+RD++cAnH4l/2W/oXxiufyELeq1/vrj/
MvjngeeHS/xrgn8/4/1L4J/Ed+7H+UPh3+eYTy78q8D84uDfJcx3P/xbhPnX
wD/9fs5J/MP/LzbCflXwbzn2bwz/FiIfCvjXiPzkwj875MsZ/u1F/pbAv3Lk
Mw7+dSO/DP9kyLcW/m1E/gvhn4XEv12D+8Mjxw72z3S76J87/BsY/P2ETd1F
f4vgnxz93gf/5PCvG/59AB8i4Z81/HCFf5nwpRP+Sb5/8WH41Ab/bODXTPiX
Dd/uvta/rOv/AKm0opE=
       "]]}}, {{}, {}}}},
  AspectRatio->Automatic,
  DisplayFunction->Identity,
  PlotRange->All]], "Output",
 CellChangeTimes->{3.81158048439961*^9, 3.811580605162813*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"f7a6cff9-1041-406a-819d-4c5fa137aea6"]
}, Open  ]],

Cell["Duplicate this plot to form the figure.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ec19e250-739b-422b-8202-b0fa231caa9e"],

Cell[CellGroupData[{

Cell["Show[GraphicsGrid[{{basic,basic,basic,basic,basic}}]]", "Input",
 CellChangeTimes->{{3.811580512564948*^9, 3.811580533585374*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[6]:=",ExpressionUUID->"eceb42ef-f69f-47b1-9cdf-1e0191672987"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
        1.1}, {-1.1, -1.1}}], 
       {PointSize[0.1], PointBox[{0, 0}]}, CircleBox[{0, 0}, 1], {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.009166666666666668], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJyN1ntQVGUYBvDFSETHDEUR0cAxL7mTlSimgS8IityisfIygo4GXiIFQRlS
1EkEyxuYAuLUICAkIJqAISLzsoiahMoCgiy3XW6uICvKTSccqvme/YOTzMgM
wx9n9pzzve/z/NipG/1X+A6TyWQJ//7+9/dI4LGXibMqSIafa9v9dsamldNB
r6VlSYVXaO69+LMGVEY0rVd53/4mxfYcmX1hVCnlhD0sDbl2j0x+8bzj80Mx
dRamVl46XE7F+61KLpsXUbPTvqhTllVk817sFhfva+Shqjt+1VJFK1YmydXP
fqPjkw9pK6JrafatxBzl6HDuCvw9cW1kPZnsqavxm3eZQ3e7N40YrSaV29XK
8pPMhf0zMnYkqKnb8aMeC+Ut3mw/Ye0fIzXUt02xKTf5LrudvNTQ6aGhFybn
nMOtyniDT/y2KH8Nee/Z17vK8wFHya2i/II0ZPk072Sv90PO+dF0TYWXhlYH
99lGu9VwUVZBWvocDZkuiuy9a1bPreZNAYHtamof822W/QY1F1p8HLo6Wk3K
vnFr1MkajjUYNtFljppCFYra+upGdtAlW7f7N9AiswPt6181sVvZrK3XN9dT
y/Kg5mPvtnBOwNGLmcvqaO6X33fGjGvlPw1jLliPqaUl50e0pQ1/xCYm6+Rb
bqhoGOtULx8/4hZ31xtOvtUUuCanNTNfyx1BU+af6K2iitMDYW8deMxpdh4p
upBK+pScn05Y0Mbq+MSu2o4Kuuhw4fb4ujaOsBjuyCvLqbLhw+LpO9v5VOqz
noZsJbnHmCdt7W9njjKauNO4lF4Y7rovC37CERv+LrBNL6EeUv5kpHnCWa+8
M5vm3aHIfCuOsetg7dTxwdrLNyngOyPjoiMd3LjFZpL9+4XkPqBIT/irgxNn
xi09Y5FPm87bxSx+1cHO8dbTb6mv0Na4Vd+kWOk4RNl8b8aCDDqoDVurma/j
qoHAEIPFv1Kp/Kvgblsdm3+WKt+YcdZWcp0ln2fJ/Vn//IPi+bwD71cu3o9P
4P1rxPtzH86XIs7HkvOzZD6sn99RMT/OwHzDxXzZBvN/JObPD7CfZLEf1u9P
J/bHhthvg9gvL8X+3xH7Z0k+WIv8ZIn8sA3y5SHyxbuRPyeRPy5DPk+LfLIk
vzwF+W4S+eZ1yP9NkX+ehH5cFf1gL/QnUvSHuwb3iyX94zb001f0kyX95Wno
917Rb25G//tE/7nra+FDtPCBJ8MPT+EHZ8MXnfCFR8GfHuEPx8CnbOETfwK/
nIRfnAvf9gvfWO+fGeUZ1DokXc/DdRf4txCfnwz/9PfPh3+WeH7bG/qXCP8i
4N/62+L8L+CfscS/25ifAv6pMF8f+FeF+bsO4d8qiX/jsN/cIfwbJfGvE/kp
gH/3ka8z8E+Sv//5V4P8FsA/W+Q7H/45Iv9j4d/b6Ica/gWgP8+H8G8h+qeB
f5J+Uhn6G/+G/nXBB4XEv2r4p/fl+RD++cAnH4l/2W/oXxiufyELeq1/vrj/
MvjngeeHS/xrgn8/4/1L4J/Ed+7H+UPh3+eYTy78q8D84uDfJcx3P/xbhPnX
wD/9fs5J/MP/LzbCflXwbzn2bwz/FiIfCvjXiPzkwj875MsZ/u1F/pbAv3Lk
Mw7+dSO/DP9kyLcW/m1E/gvhn4XEv12D+8Mjxw72z3S76J87/BsY/P2ETd1F
f4vgnxz93gf/5PCvG/59AB8i4Z81/HCFf5nwpRP+Sb5/8WH41Ab/bODXTPiX
Dd/uvta/rOv/AKm0opE=
           "]]}}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.}, {1., 0.}},
      PlotRange->All], {195., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
        1.1}, {-1.1, -1.1}}], 
       {PointSize[0.1], PointBox[{0, 0}]}, CircleBox[{0, 0}, 1], {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.009166666666666668], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJyN1ntQVGUYBvDFSETHDEUR0cAxL7mTlSimgS8IityisfIygo4GXiIFQRlS
1EkEyxuYAuLUICAkIJqAISLzsoiahMoCgiy3XW6uICvKTSccqvme/YOTzMgM
wx9n9pzzve/z/NipG/1X+A6TyWQJ//7+9/dI4LGXibMqSIafa9v9dsamldNB
r6VlSYVXaO69+LMGVEY0rVd53/4mxfYcmX1hVCnlhD0sDbl2j0x+8bzj80Mx
dRamVl46XE7F+61KLpsXUbPTvqhTllVk817sFhfva+Shqjt+1VJFK1YmydXP
fqPjkw9pK6JrafatxBzl6HDuCvw9cW1kPZnsqavxm3eZQ3e7N40YrSaV29XK
8pPMhf0zMnYkqKnb8aMeC+Ut3mw/Ye0fIzXUt02xKTf5LrudvNTQ6aGhFybn
nMOtyniDT/y2KH8Nee/Z17vK8wFHya2i/II0ZPk072Sv90PO+dF0TYWXhlYH
99lGu9VwUVZBWvocDZkuiuy9a1bPreZNAYHtamof822W/QY1F1p8HLo6Wk3K
vnFr1MkajjUYNtFljppCFYra+upGdtAlW7f7N9AiswPt6181sVvZrK3XN9dT
y/Kg5mPvtnBOwNGLmcvqaO6X33fGjGvlPw1jLliPqaUl50e0pQ1/xCYm6+Rb
bqhoGOtULx8/4hZ31xtOvtUUuCanNTNfyx1BU+af6K2iitMDYW8deMxpdh4p
upBK+pScn05Y0Mbq+MSu2o4Kuuhw4fb4ujaOsBjuyCvLqbLhw+LpO9v5VOqz
noZsJbnHmCdt7W9njjKauNO4lF4Y7rovC37CERv+LrBNL6EeUv5kpHnCWa+8
M5vm3aHIfCuOsetg7dTxwdrLNyngOyPjoiMd3LjFZpL9+4XkPqBIT/irgxNn
xi09Y5FPm87bxSx+1cHO8dbTb6mv0Na4Vd+kWOk4RNl8b8aCDDqoDVurma/j
qoHAEIPFv1Kp/Kvgblsdm3+WKt+YcdZWcp0ln2fJ/Vn//IPi+bwD71cu3o9P
4P1rxPtzH86XIs7HkvOzZD6sn99RMT/OwHzDxXzZBvN/JObPD7CfZLEf1u9P
J/bHhthvg9gvL8X+3xH7Z0k+WIv8ZIn8sA3y5SHyxbuRPyeRPy5DPk+LfLIk
vzwF+W4S+eZ1yP9NkX+ehH5cFf1gL/QnUvSHuwb3iyX94zb001f0kyX95Wno
917Rb25G//tE/7nra+FDtPCBJ8MPT+EHZ8MXnfCFR8GfHuEPx8CnbOETfwK/
nIRfnAvf9gvfWO+fGeUZ1DokXc/DdRf4txCfnwz/9PfPh3+WeH7bG/qXCP8i
4N/62+L8L+CfscS/25ifAv6pMF8f+FeF+bsO4d8qiX/jsN/cIfwbJfGvE/kp
gH/3ka8z8E+Sv//5V4P8FsA/W+Q7H/45Iv9j4d/b6Ica/gWgP8+H8G8h+qeB
f5J+Uhn6G/+G/nXBB4XEv2r4p/fl+RD++cAnH4l/2W/oXxiufyELeq1/vrj/
MvjngeeHS/xrgn8/4/1L4J/Ed+7H+UPh3+eYTy78q8D84uDfJcx3P/xbhPnX
wD/9fs5J/MP/LzbCflXwbzn2bwz/FiIfCvjXiPzkwj875MsZ/u1F/pbAv3Lk
Mw7+dSO/DP9kyLcW/m1E/gvhn4XEv12D+8Mjxw72z3S76J87/BsY/P2ETd1F
f4vgnxz93gf/5PCvG/59AB8i4Z81/HCFf5nwpRP+Sb5/8WH41Ab/bODXTPiX
Dd/uvta/rOv/AKm0opE=
           "]]}}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.}, {1., 0.}},
      PlotRange->All], {585., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
        1.1}, {-1.1, -1.1}}], 
       {PointSize[0.1], PointBox[{0, 0}]}, CircleBox[{0, 0}, 1], {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.009166666666666668], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJyN1ntQVGUYBvDFSETHDEUR0cAxL7mTlSimgS8IityisfIygo4GXiIFQRlS
1EkEyxuYAuLUICAkIJqAISLzsoiahMoCgiy3XW6uICvKTSccqvme/YOTzMgM
wx9n9pzzve/z/NipG/1X+A6TyWQJ//7+9/dI4LGXibMqSIafa9v9dsamldNB
r6VlSYVXaO69+LMGVEY0rVd53/4mxfYcmX1hVCnlhD0sDbl2j0x+8bzj80Mx
dRamVl46XE7F+61KLpsXUbPTvqhTllVk817sFhfva+Shqjt+1VJFK1YmydXP
fqPjkw9pK6JrafatxBzl6HDuCvw9cW1kPZnsqavxm3eZQ3e7N40YrSaV29XK
8pPMhf0zMnYkqKnb8aMeC+Ut3mw/Ye0fIzXUt02xKTf5LrudvNTQ6aGhFybn
nMOtyniDT/y2KH8Nee/Z17vK8wFHya2i/II0ZPk072Sv90PO+dF0TYWXhlYH
99lGu9VwUVZBWvocDZkuiuy9a1bPreZNAYHtamof822W/QY1F1p8HLo6Wk3K
vnFr1MkajjUYNtFljppCFYra+upGdtAlW7f7N9AiswPt6181sVvZrK3XN9dT
y/Kg5mPvtnBOwNGLmcvqaO6X33fGjGvlPw1jLliPqaUl50e0pQ1/xCYm6+Rb
bqhoGOtULx8/4hZ31xtOvtUUuCanNTNfyx1BU+af6K2iitMDYW8deMxpdh4p
upBK+pScn05Y0Mbq+MSu2o4Kuuhw4fb4ujaOsBjuyCvLqbLhw+LpO9v5VOqz
noZsJbnHmCdt7W9njjKauNO4lF4Y7rovC37CERv+LrBNL6EeUv5kpHnCWa+8
M5vm3aHIfCuOsetg7dTxwdrLNyngOyPjoiMd3LjFZpL9+4XkPqBIT/irgxNn
xi09Y5FPm87bxSx+1cHO8dbTb6mv0Na4Vd+kWOk4RNl8b8aCDDqoDVurma/j
qoHAEIPFv1Kp/Kvgblsdm3+WKt+YcdZWcp0ln2fJ/Vn//IPi+bwD71cu3o9P
4P1rxPtzH86XIs7HkvOzZD6sn99RMT/OwHzDxXzZBvN/JObPD7CfZLEf1u9P
J/bHhthvg9gvL8X+3xH7Z0k+WIv8ZIn8sA3y5SHyxbuRPyeRPy5DPk+LfLIk
vzwF+W4S+eZ1yP9NkX+ehH5cFf1gL/QnUvSHuwb3iyX94zb001f0kyX95Wno
917Rb25G//tE/7nra+FDtPCBJ8MPT+EHZ8MXnfCFR8GfHuEPx8CnbOETfwK/
nIRfnAvf9gvfWO+fGeUZ1DokXc/DdRf4txCfnwz/9PfPh3+WeH7bG/qXCP8i
4N/62+L8L+CfscS/25ifAv6pMF8f+FeF+bsO4d8qiX/jsN/cIfwbJfGvE/kp
gH/3ka8z8E+Sv//5V4P8FsA/W+Q7H/45Iv9j4d/b6Ica/gWgP8+H8G8h+qeB
f5J+Uhn6G/+G/nXBB4XEv2r4p/fl+RD++cAnH4l/2W/oXxiufyELeq1/vrj/
MvjngeeHS/xrgn8/4/1L4J/Ed+7H+UPh3+eYTy78q8D84uDfJcx3P/xbhPnX
wD/9fs5J/MP/LzbCflXwbzn2bwz/FiIfCvjXiPzkwj875MsZ/u1F/pbAv3Lk
Mw7+dSO/DP9kyLcW/m1E/gvhn4XEv12D+8Mjxw72z3S76J87/BsY/P2ETd1F
f4vgnxz93gf/5PCvG/59AB8i4Z81/HCFf5nwpRP+Sb5/8WH41Ab/bODXTPiX
Dd/uvta/rOv/AKm0opE=
           "]]}}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.}, {1., 0.}},
      PlotRange->All], {975., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}], 
    InsetBox[
     GraphicsBox[{
       LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
        1.1}, {-1.1, -1.1}}], 
       {PointSize[0.1], PointBox[{0, 0}]}, CircleBox[{0, 0}, 1], {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.009166666666666668], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJyN1ntQVGUYBvDFSETHDEUR0cAxL7mTlSimgS8IityisfIygo4GXiIFQRlS
1EkEyxuYAuLUICAkIJqAISLzsoiahMoCgiy3XW6uICvKTSccqvme/YOTzMgM
wx9n9pzzve/z/NipG/1X+A6TyWQJ//7+9/dI4LGXibMqSIafa9v9dsamldNB
r6VlSYVXaO69+LMGVEY0rVd53/4mxfYcmX1hVCnlhD0sDbl2j0x+8bzj80Mx
dRamVl46XE7F+61KLpsXUbPTvqhTllVk817sFhfva+Shqjt+1VJFK1YmydXP
fqPjkw9pK6JrafatxBzl6HDuCvw9cW1kPZnsqavxm3eZQ3e7N40YrSaV29XK
8pPMhf0zMnYkqKnb8aMeC+Ut3mw/Ye0fIzXUt02xKTf5LrudvNTQ6aGhFybn
nMOtyniDT/y2KH8Nee/Z17vK8wFHya2i/II0ZPk072Sv90PO+dF0TYWXhlYH
99lGu9VwUVZBWvocDZkuiuy9a1bPreZNAYHtamof822W/QY1F1p8HLo6Wk3K
vnFr1MkajjUYNtFljppCFYra+upGdtAlW7f7N9AiswPt6181sVvZrK3XN9dT
y/Kg5mPvtnBOwNGLmcvqaO6X33fGjGvlPw1jLliPqaUl50e0pQ1/xCYm6+Rb
bqhoGOtULx8/4hZ31xtOvtUUuCanNTNfyx1BU+af6K2iitMDYW8deMxpdh4p
upBK+pScn05Y0Mbq+MSu2o4Kuuhw4fb4ujaOsBjuyCvLqbLhw+LpO9v5VOqz
noZsJbnHmCdt7W9njjKauNO4lF4Y7rovC37CERv+LrBNL6EeUv5kpHnCWa+8
M5vm3aHIfCuOsetg7dTxwdrLNyngOyPjoiMd3LjFZpL9+4XkPqBIT/irgxNn
xi09Y5FPm87bxSx+1cHO8dbTb6mv0Na4Vd+kWOk4RNl8b8aCDDqoDVurma/j
qoHAEIPFv1Kp/Kvgblsdm3+WKt+YcdZWcp0ln2fJ/Vn//IPi+bwD71cu3o9P
4P1rxPtzH86XIs7HkvOzZD6sn99RMT/OwHzDxXzZBvN/JObPD7CfZLEf1u9P
J/bHhthvg9gvL8X+3xH7Z0k+WIv8ZIn8sA3y5SHyxbuRPyeRPy5DPk+LfLIk
vzwF+W4S+eZ1yP9NkX+ehH5cFf1gL/QnUvSHuwb3iyX94zb001f0kyX95Wno
917Rb25G//tE/7nra+FDtPCBJ8MPT+EHZ8MXnfCFR8GfHuEPx8CnbOETfwK/
nIRfnAvf9gvfWO+fGeUZ1DokXc/DdRf4txCfnwz/9PfPh3+WeH7bG/qXCP8i
4N/62+L8L+CfscS/25ifAv6pMF8f+FeF+bsO4d8qiX/jsN/cIfwbJfGvE/kp
gH/3ka8z8E+Sv//5V4P8FsA/W+Q7H/45Iv9j4d/b6Ica/gWgP8+H8G8h+qeB
f5J+Uhn6G/+G/nXBB4XEv2r4p/fl+RD++cAnH4l/2W/oXxiufyELeq1/vrj/
MvjngeeHS/xrgn8/4/1L4J/Ed+7H+UPh3+eYTy78q8D84uDfJcx3P/xbhPnX
wD/9fs5J/MP/LzbCflXwbzn2bwz/FiIfCvjXiPzkwj875MsZ/u1F/pbAv3Lk
Mw7+dSO/DP9kyLcW/m1E/gvhn4XEv12D+8Mjxw72z3S76J87/BsY/P2ETd1F
f4vgnxz93gf/5PCvG/59AB8i4Z81/HCFf5nwpRP+Sb5/8WH41Ab/bODXTPiX
Dd/uvta/rOv/AKm0opE=
           "]]}}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.}, {1., 0.}},
      PlotRange->All], {1365., -189.}, ImageScaled[{0.5, 0.5}], {360., 360.}],
     InsetBox[
     GraphicsBox[{
       LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
        1.1}, {-1.1, -1.1}}], 
       {PointSize[0.1], PointBox[{0, 0}]}, CircleBox[{0, 0}, 1], {{}, {{}, {}, 
         {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          0.009166666666666668], AbsoluteThickness[1.6], 
          LineBox[CompressedData["
1:eJyN1ntQVGUYBvDFSETHDEUR0cAxL7mTlSimgS8IityisfIygo4GXiIFQRlS
1EkEyxuYAuLUICAkIJqAISLzsoiahMoCgiy3XW6uICvKTSccqvme/YOTzMgM
wx9n9pzzve/z/NipG/1X+A6TyWQJ//7+9/dI4LGXibMqSIafa9v9dsamldNB
r6VlSYVXaO69+LMGVEY0rVd53/4mxfYcmX1hVCnlhD0sDbl2j0x+8bzj80Mx
dRamVl46XE7F+61KLpsXUbPTvqhTllVk817sFhfva+Shqjt+1VJFK1YmydXP
fqPjkw9pK6JrafatxBzl6HDuCvw9cW1kPZnsqavxm3eZQ3e7N40YrSaV29XK
8pPMhf0zMnYkqKnb8aMeC+Ut3mw/Ye0fIzXUt02xKTf5LrudvNTQ6aGhFybn
nMOtyniDT/y2KH8Nee/Z17vK8wFHya2i/II0ZPk072Sv90PO+dF0TYWXhlYH
99lGu9VwUVZBWvocDZkuiuy9a1bPreZNAYHtamof822W/QY1F1p8HLo6Wk3K
vnFr1MkajjUYNtFljppCFYra+upGdtAlW7f7N9AiswPt6181sVvZrK3XN9dT
y/Kg5mPvtnBOwNGLmcvqaO6X33fGjGvlPw1jLliPqaUl50e0pQ1/xCYm6+Rb
bqhoGOtULx8/4hZ31xtOvtUUuCanNTNfyx1BU+af6K2iitMDYW8deMxpdh4p
upBK+pScn05Y0Mbq+MSu2o4Kuuhw4fb4ujaOsBjuyCvLqbLhw+LpO9v5VOqz
noZsJbnHmCdt7W9njjKauNO4lF4Y7rovC37CERv+LrBNL6EeUv5kpHnCWa+8
M5vm3aHIfCuOsetg7dTxwdrLNyngOyPjoiMd3LjFZpL9+4XkPqBIT/irgxNn
xi09Y5FPm87bxSx+1cHO8dbTb6mv0Na4Vd+kWOk4RNl8b8aCDDqoDVurma/j
qoHAEIPFv1Kp/Kvgblsdm3+WKt+YcdZWcp0ln2fJ/Vn//IPi+bwD71cu3o9P
4P1rxPtzH86XIs7HkvOzZD6sn99RMT/OwHzDxXzZBvN/JObPD7CfZLEf1u9P
J/bHhthvg9gvL8X+3xH7Z0k+WIv8ZIn8sA3y5SHyxbuRPyeRPy5DPk+LfLIk
vzwF+W4S+eZ1yP9NkX+ehH5cFf1gL/QnUvSHuwb3iyX94zb001f0kyX95Wno
917Rb25G//tE/7nra+FDtPCBJ8MPT+EHZ8MXnfCFR8GfHuEPx8CnbOETfwK/
nIRfnAvf9gvfWO+fGeUZ1DokXc/DdRf4txCfnwz/9PfPh3+WeH7bG/qXCP8i
4N/62+L8L+CfscS/25ifAv6pMF8f+FeF+bsO4d8qiX/jsN/cIfwbJfGvE/kp
gH/3ka8z8E+Sv//5V4P8FsA/W+Q7H/45Iv9j4d/b6Ica/gWgP8+H8G8h+qeB
f5J+Uhn6G/+G/nXBB4XEv2r4p/fl+RD++cAnH4l/2W/oXxiufyELeq1/vrj/
MvjngeeHS/xrgn8/4/1L4J/Ed+7H+UPh3+eYTy78q8D84uDfJcx3P/xbhPnX
wD/9fs5J/MP/LzbCflXwbzn2bwz/FiIfCvjXiPzkwj875MsZ/u1F/pbAv3Lk
Mw7+dSO/DP9kyLcW/m1E/gvhn4XEv12D+8Mjxw72z3S76J87/BsY/P2ETd1F
f4vgnxz93gf/5PCvG/59AB8i4Z81/HCFf5nwpRP+Sb5/8WH41Ab/bODXTPiX
Dd/uvta/rOv/AKm0opE=
           "]]}}, {{}, {}}}},
      AspectRatio->Automatic,
      DisplayFunction->Identity,
      ImagePadding->{{0., 1.}, {1., 0.}},
      PlotRange->All], {1755., -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.}]}, {}},
  ImageSize->{
    UpTo[600], 
    UpTo[360]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.8115804848132*^9, {3.8115805172089443`*^9, 3.811580534684531*^9}, 
   3.8115806054565783`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"13c14824-cbe8-4388-9b27-97f04dc2f77f"]
}, Open  ]],

Cell[TextData[{
 "Define a function ",
 StyleBox["PlotPathInertial", "Input"],
 " to show the paths in the inertial frame around the unit orbit and the \
resonant orbit, adding points at equal time intervals, ",
 StyleBox["dt", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"165e2b51-0439-4b6d-84d2-4f7d426b545a"],

Cell["\<\
PlotPathInertial[pl_List, e_, dt_] :=
Module[{time, p1, p2, p = Apply[Rational,pl],
        pt = If[pl[[1]] > pl[[2]], pl[[1]], pl[[2]]],
        sun=Graphics[{PointSize[0.05],Point[{0,0}]}],
        planet=Graphics[{PointSize[0.02],Point[{1.0,0.0}]}],
        porb = Graphics[{Circle[{0,0},1]}],
        a = N[(pl[[1]]/pl[[2]])^(2/3)],
        circle = Graphics[{Circle[{0,0},1]}],
        box = 
        Graphics[Line[{{-1.1,-1.1},{1.1,-1.1},
                       {1.1,1.1},{-1.1,1.1},{-1.1,-1.1}}]]},
  ptime = Table[N[t], {t,0,pt*2*Pi,Pi/40}];
  time = Table[N[t], {t,0,pt*2*Pi,dt}];
  posvec = Map[position[#,a,e]&,time];
  f = Map[N[ArcTan[#[[1]],#[[2]]]]&,posvec];
  rad = Map[N[Sqrt[#[[1]]^2+#[[2]]^2]]&,posvec];
  points2 = Transpose[{Cos[p*time],Sin[p*time]}];
  points1 = Transpose[{rad*Cos[f],rad*Sin[f]}];
  p1 = 
  ListPlot[points1,
           AspectRatio->Automatic, Axes->None,
           DisplayFunction->Identity,
           PlotRange->{{-1.1,1.1},{-1.1,1.1}}];
  p2 = 
  ListPlot[points2,
           AspectRatio->Automatic, Axes->None,
           DisplayFunction->Identity,
           PlotRange->{{-1.1,1.1},{-1.1,1.1}}];
  posvec = Map[position[#,a,e]&,ptime];
  f = Map[N[ArcTan[#[[1]],#[[2]]]]&,posvec];
  rad = Map[N[Sqrt[#[[1]]^2+#[[2]]^2]]&,posvec];
  orbpts = Transpose[{rad*Cos[f],rad*Sin[f]}];
  p3 = 
  ListPlot[orbpts,
           PlotJoined->True,
           AspectRatio->Automatic, Axes->None,
           DisplayFunction->Identity,
           PlotRange->{{-1.1,1.1},{-1.1,1.1}}];
  Show[box,sun,planet,circle,p1,p2,p3,
       DisplayFunction->$DisplayFunction,
  AspectRatio->Automatic,PlotRange->All]]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"d8233bb1-3ae6-4b89-9ac4-9b16b6e65e86"],

Cell["\<\
Plot the paths in the inertial frame for the 2:1 resonance with points at \
time intervals of \[Pi]/4.  This gives the basic plot for Fig.8.3a.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a8a3f3a5-d4d3-4498-a5ef-9205eee5848c"],

Cell[CellGroupData[{

Cell["p = PlotPathInertial[{1,2}, 0.2, Pi/4]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"71ff4ec0-2b5c-4bb9-8bf2-666d6444d2ee"],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
    1.1}, {-1.1, -1.1}}], 
   {PointSize[0.05], PointBox[{0, 0}]}, 
   {PointSize[0.02], PointBox[{1., 0.}]}, CircleBox[{0, 0}, 1], {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{0.5039684199579493, 0.}, {0.24155727517501763`, 
      0.5012857543232488}, {-0.24877684075526632`, 
      0.6053950815696957}, {-0.6227289741433344, 
      0.37960326129088}, {-0.7559526299369239, 
      9.257749685592775*^-17}, {-0.6227289741433345, -0.37960326129088007`}, \
{-0.2487768407552666, -0.6053950815696957}, {
      0.24155727517501713`, -0.5012857543232493}, {
      0.5039684199579493, -1.511784193074246*^-16}, {0.24155727517501793`, 
      0.5012857543232486}, {-0.24877684075526632`, 
      0.6053950815696957}, {-0.6227289741433341, 
      0.37960326129088057`}, {-0.7559526299369239, 
      4.282879029686931*^-16}, {-0.6227289741433344, -0.37960326129088}, \
{-0.2487768407552668, -0.6053950815696957}, {
      0.24155727517501657`, -0.5012857543232495}, {
      0.5039684199579493, -3.023568386148492*^-16}}]}, {{}, {}}}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{1., 0.}, {0.9238795325112867, 0.3826834323650898}, {
      0.7071067811865476, 0.7071067811865475}, {0.38268343236508984`, 
      0.9238795325112867}, {6.123233995736766*^-17, 1.}, {-0.3826834323650897,
       0.9238795325112867}, {-0.7071067811865475, 
      0.7071067811865476}, {-0.9238795325112867, 0.38268343236508984`}, {-1., 
      1.2246467991473532`*^-16}, {-0.9238795325112867, \
-0.38268343236508967`}, {-0.7071067811865477, -0.7071067811865475}, \
{-0.38268343236509034`, -0.9238795325112865}, {-1.8369701987210297`*^-16, \
-1.}, {0.38268343236509, -0.9238795325112866}, {
      0.7071067811865475, -0.7071067811865477}, {
      0.9238795325112865, -0.3826834323650904}, {
      1., -2.4492935982947064`*^-16}}]}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJyV1WtQVGUYB3ACDUFESCV01FDM1NHRQtRV4MEAJdDRgcJkyduwKYIlaSIC
IopBNwMKc4QwSgRdYE1DVkUfwCspqy6gCCy3o0AxXgEnLCzr/e+HPeaHmNnh
w5lzzvs+7///O2NWfRigMjczM8t++vvnv1uP+8rtTs1khr+L2xZ1FFg20zxD
7zsZjwrp2txBo9+OaaIFGYOXTLxwmtrHFW4+ntRIudmvOd6sO0+He4+4WikM
lBVul2thq6PsvqUuM9LraWiY31XDRj2FNllpl/14k7w1dSHfFtZQ18cd+THh
N6hvrTpmYkEtRXbFkd2japqz0OHUk7X1VPjVwswmfz3ND77Q/zfJQLo1W/2W
durIItMxItm6mY4PbVQO/P0ivVir1queNFNZlrNKoSsnV8f33/CsbKFIZdyC
gsdaStt9aYd7VCtZjLhjb7Uoj/6qC/OU/mylII9XokoD1nDSHO3YfsslqtCv
uGe7RM2zhtsf1WRJtCF5fVhC3Am+56Ftdz4l0dTphlsb087wrM6attKTEgWt
sbk+8mIFd636uvpJhkTpt3eqOm9c4d4BKQmqp8/71Cn10BaDnqNz7pbvtJTo
3N0Ryl1FNVxh16LoTm8lzbjJG7ZG1vIQzdgAH5tWetnK6lKnbT3Pt3T1so5o
oX0T8lPKPjewpVvfbd2xZrqcGzp1SlsTpwzyWjetoYls/BNj/W1bWBHtW3Z+
fCPtGBJ4odKhlZdHlkf6LW6gTH2emYWNxJLWZeQ3yjrSds1brLojcWvp5C3h
/rWU8Hika8KJW6x5PPFh0tjr9CCzOKnro9scmKDenCpV0aTAP0pXO7TxlxPc
CsekXqPXTy2J372/jd9K2BX0mVJHGZPG+HiPauczy7rre6MqKCQoMNxzWzsX
xHqVx8eepU2rs71DK9t5dLWy+kH9aUr8KWRdWr8ODk5+MCzsh5/ppU0rfY69
2sGG7qMejer9VHevIfXMtA7uOWsbbaHZ62aP6zHiOhvvf1Pcz8bnDxDP52C8
Xy3ez99hfefE+nga1u8r1s+y/fF97H+p2D/L5sPHMT9JzI+zMN8mMV9Owvzf
E/PnwTifmeJ8+CrOb5c4Py7A+ZqL8+VRpufP+ciHvcgHs2l+OBH52iLyxftM
88crkM+HIp/sivwqRH75IPJ9X+SbHapE/meK/LOTu0k/eAj60yf6w1+gX6mi
X1xi2j8uRT/7i35yCfprKfrLOej3ItFv/gD9dxf95zvwwSz8Xx94BfzwEX7w
9/BlhPCFjf7sE/6wzCc2+uUr/GKjb0OFb2z0b7P3/cvxFTklv+D6rw3Cvyrc
PxD+deD5hfDvCN6/W+bfMJl/BP96sb8e+LcW+/eEf/mYjz/8u4n5vQD/KjFf
C/h3A/N3gX8xMv8UpudHR2eL8/0E/hlk/oXJ/KP/6d9W03zSYeS3Ev4VI992
z/HvIPrRD/6Voz974J81+kXP8U/WTypCfztl/h2Ef7L+P+PfVPgRCP/2wpcG
+Gf0Ryvzbwb82w6/3pX5ly/zzzHbaX1iw2k343WbHuHfDtw/V+YffGWZv2xc
3xX454L1e8C/Kdjfdvgn858TMZ8D8E/2/eBszLcG/u3E/JXwT/Z9Ytn36xn/
nHH+PvCvDPmwhX8nkZ9L8G8P8hUF/w7I/Fttmk+ebZpf9jTNN8vyz3EKk35w
8HDRH/N64d909Csd/hWhfzPhXwH6aQn/8tBfK/inRr/94F8E+k8y/8zhnwp+
eMC/PfBlPPw7BH+K4Z8En/Tw7zL8CpD5F/2f/hWV/A3OgGjl
       "]]}}, {{}, {}}}},
  AspectRatio->Automatic,
  DisplayFunction->Identity,
  PlotRange->All]], "Output",
 CellChangeTimes->{3.8115804849604053`*^9, 3.811580605575981*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"6285528d-b4b4-4714-9131-f9ee3dce17ca"]
}, Open  ]],

Cell[TextData[{
 "Define a function ",
 StyleBox["PlotPathRotate", "Input"],
 " to show the paths in the rotating frame around the unit orbit and the \
resonant orbit, adding points at equal time intervals, ",
 StyleBox["dt", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6f826f99-88ed-49ea-830d-c748cf1817fd"],

Cell["\<\
PlotPathRotate[pl_List, e_, dt_] :=
Module[{p = Apply[Rational,Reverse[pl]],
        pt = If[pl[[1]] > pl[[2]], pl[[1]], pl[[2]]],
        sun=Graphics[{PointSize[0.05],Point[{0,0}]}],
        planet=Graphics[{PointSize[0.02],Point[{1.0,0.0}]}],
        porb = Graphics[{Circle[{0,0},1]}],
        a = N[(pl[[1]]/pl[[2]])^(2/3)],
        circle = Graphics[{Circle[{0,0},1]}],
        box = 
        Graphics[Line[{{-1.1,-1.1},{1.1,-1.1},
                       {1.1,1.1},{-1.1,1.1},{-1.1,-1.1}}]]},
  time = Table[N[t], {t,0,pt*2*Pi,dt}];
  ptime = Table[N[t], {t,0,pt*2*Pi,Pi/40}];
  posvec = Map[position[#,a,e]&,time];
  f = Map[N[ArcTan[#[[1]],#[[2]]]]&,posvec];
  rad = Map[N[Sqrt[#[[1]]^2+#[[2]]^2]]&,posvec];
  points = Transpose[{rad*Cos[f-time/p],rad*Sin[f-time/p]}];
  p1 = 
  ListPlot[points,
           AspectRatio->Automatic, Axes->None,
           DisplayFunction->Identity,
           PlotRange->{{-1.1,1.1},{-1.1,1.1}}];
  posvec = Map[position[#,a,e]&,ptime];
  f = Map[N[ArcTan[#[[1]],#[[2]]]]&,posvec];
  rad = Map[N[Sqrt[#[[1]]^2+#[[2]]^2]]&,posvec];
  orbpts = Transpose[{rad*Cos[f-ptime/p],rad*Sin[f-ptime/p]}];
  p3 = 
  ListPlot[orbpts,
           PlotJoined->True,
           AspectRatio->Automatic, Axes->None,
           DisplayFunction->Identity,
           PlotRange->{{-1.1,1.1},{-1.1,1.1}}];
  Show[box,sun,planet,p1,p3,
       DisplayFunction->$DisplayFunction,
  AspectRatio->Automatic,PlotRange->All]]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[9]:=",ExpressionUUID->"d7d5cc3f-fbfd-4225-848c-417d2417b52a"],

Cell["\<\
Plot the paths in the rotating frame for the 2:1 resonance with points at \
time intervals of \[Pi]/4.  This gives the basic plot for Fig.8.3b.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1ef09b45-1bfe-4315-a91f-b003281dd163"],

Cell[CellGroupData[{

Cell["p = PlotPathRotate[{1,2}, 0.2, Pi/4]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[10]:=",ExpressionUUID->"60e6a205-9c3d-479a-a076-30198971c8f2"],

Cell[BoxData[
 GraphicsBox[{
   LineBox[{{-1.1, -1.1}, {1.1, -1.1}, {1.1, 1.1}, {-1.1, 
    1.1}, {-1.1, -1.1}}], 
   {PointSize[0.05], PointBox[{0, 0}]}, 
   {PointSize[0.02], PointBox[{1., 0.}]}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{0.5039684199579493, 0.}, {0.4150035755235396, 
      0.3706876811819967}, {0.2521671763747002, 0.6039907585751296}, {
      0.1123996223228156, 0.720594432480553}, {4.6288748427963873`*^-17, 
      0.7559526299369239}, {-0.11239962232281572`, 
      0.7205944324805531}, {-0.25216717637470004`, 
      0.6039907585751297}, {-0.41500357552353934`, 
      0.3706876811819971}, {-0.5039684199579493, 
      1.6208860617122506`*^-16}, {-0.4150035755235398, -0.3706876811819963}, \
{-0.2521671763747001, -0.6039907585751296}, {-0.11239962232281585`, \
-0.720594432480553}, {-2.8942165768480144`*^-16, -0.7559526299369239}, {
      0.11239962232281578`, -0.720594432480553}, {
      0.2521671763747002, -0.6039907585751298}, {
      0.41500357552353906`, -0.3706876811819974}, {
      0.5039684199579493, -3.241772123424501*^-16}}]}, {{}, {}}}, {{}, {{}, \
{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVlntQlGUUxkkMGBUvDYk3UEguWrDoGGJAp9QCzWQAFUxRMUAdrgJKOslN
CFxCXPOaeBuMi6Zhoo6JczKRQSsFYUFBLgLLLoo4uq3VJFpxnv1jmdnhj2++
7z3veZ7nd47D2vigyCFmZmbH//v9/9/H4BueOaWDzPDnseq8w5+2HbTLct2e
K20nyI7f8LMaaKeZbke1Bb9XUNqY+pjIsnYKGarPsxjGlO9g9XWlZzu9pj4X
UqGsor6hh3WLS9poTlF51ZCNN0h3cbSyZqCVUruKA21m3qKsaY6j7H1bKWrW
6dOqiDo6ULp/YvT6+1R7esq+Dw/W0/MrO+/WZ7aQ/9/7M2+eV1Odwtk1uqCZ
orwf3wm91ERD13gttVfdo+WeceXZRfco52xAULHyLv141H3Ox8ktFK1vHZea
2kSaovuBzW+30ptrj8S0xjWSvs3Rp/JmG+2Ir3W+GKamUJ9GdY1rB3l4J7n9
tKiBMpKiVxd0dFBPmDJgiW89TS0NT7PLf0DXdu9cdcHjDqmzIty73TtpZJzH
q7sudRS3aKH5supOcm3p/TXjrVqaGxwZ2x3cRc4p75ip/G+R13sjjg80dZH9
5b+ezV76GyWUbRs3PLibyqimIz/2JiWoQ/MTrndT53cvS3SqGvrje31gnkJD
1iml2VG/VJPPmPmGsyoNHQza5G14WUULElImz+rT0NQjEzeG+l2jwqStBz6j
Hso6NCFMcegqTXfdFrMur4cSU4bl6vVMqlOaqftqe8haZbjiVV1JGR1OIyeN
0lJhf07yjVOXKN9QkOXqpyVrG98544su0NothfM0X2jpzJMa660nz9GKZ84V
m09oadoE//MOP5eTsvyl54sbWnre5tewsuoUWYyt37CrV0vVFiHTl9kVU0Dj
65ELzHX0eWSyl3POMbodEfTUy1ZH9X0RSSH/7KUtyV9VxDjpaMNDb7fbz7Ip
Kfnqkn43HRmqRm4x/0Hp0/zkvuqah46+7B18zol4ni/v81a8v1y+z8bvH5fz
+VOcb9c+WB9boT6F1M+5qL9M7sfG+82V+3M47p8u/eGd6I+N9I8z0b9Y6S8b
+5sq/Wc39N9d9OHD0Ge36MefQL++zYP6MkHfFtGfn0P/k+IPjoM/4B+Og3+8
xF/sCX85if94Hvw3TPzJRn9eF/9yI/zbKf7mafC3q/ift8P/SskHhyAfYyU/
3I/8JEq++AHylSX54wrkz1LyycHI5y3JL8civ3rJNwcg3/sk/1yP/KcLH3g9
+KARfnA6+AG+8AfgC/jDZuBPqvCJV4BP4Be7g18K4RtHg2/gH9eVOnxrvrLE
ZwaekzznSXjfQt7ndHw/Ur7PxvMHGgbP50eoz1vq417Uv0nq52zcb43cj/fi
/g1yfzagP4ulP6xG/1ZL/9gK/Q2S/nIu+n9G+s/x0KdT9GFb6Ncn+nEe9F0m
+rIC+oN/rIE/nMQfDP5xk/iHR8FfseIvdob/wD+eYepP9oR/Y8S/XAJ/g3/c
Dv8bxP/8wjQffAz58Zf8sItpvjgD+QP/eI1pPnky8gv+8UbkG/xje+Qf/ONz
pnzgQFN+8AzwxVL4wlrwZ7Hwh9835RPbPhZ+pQi/eAz4Bv6xt+1lx67mikrw
j999ZMJHLjblJ0eZ8pVHWwp/jee7tJvwmT3B7x2oPwN8D8P9xpvyn3MwHwrQ
nwmm84M/wnzZjf6mmc4fVmA+HYI+ezC/FkK/J6IvGfVtw/wD/7gQ8zER/nDE
/IyHf2wwX73hLxfM3/nw3wjM53j4sxrzG/zjp5jvU+DvmZj/6fD/N9gPgpGP
4dgfXiE/Udgv+pEv4/5xAfkbWC37STjyWYP9JQn5Rb5pAfK9B/uPGvlPw34U
Cz48xP4UD37osF8tBV9ysX/ZC/+MfKId4NM47G+zwS/jfrcdfDPuf8K/i5X/
AgzMSsw=
       "]]}}, {{}, {}}}},
  AspectRatio->Automatic,
  DisplayFunction->Identity,
  PlotRange->All]], "Output",
 CellChangeTimes->{3.811580485076404*^9, 3.811580605724942*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"2f7f124c-7f24-4707-ae1e-d48444526181"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{923, 653},
WindowMargins->{{14, Automatic}, {Automatic, 260}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"f58d3e80-3f29-47d4-a321-113775469800"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 119, 0, 67, "Section",ExpressionUUID->"ab46d1d4-c274-4c7e-aecc-dd20d81f12d5"],
Cell[680, 22, 232, 6, 49, "Text",ExpressionUUID->"10b5fc25-e6ed-49be-9d0e-47c77287d93b"],
Cell[915, 30, 188, 3, 30, "Input",ExpressionUUID->"7c0deb6a-4ae7-440c-9eae-af92720ee1f0"],
Cell[1106, 35, 319, 8, 76, "Text",ExpressionUUID->"89ee7715-d7d3-4c9f-b8e7-6088cc8a6986"],
Cell[1428, 45, 212, 3, 30, "Input",ExpressionUUID->"cce93ea9-b5fb-4b3b-af06-d350e6933f7e"],
Cell[1643, 50, 369, 13, 53, "Text",ExpressionUUID->"d7c56dea-670d-415c-af27-0b76c2e00f4b"],
Cell[2015, 65, 263, 8, 84, "Input",ExpressionUUID->"aacec0b2-7773-468d-aba4-26a9bce8903a"],
Cell[2281, 75, 476, 13, 76, "Text",ExpressionUUID->"e85f1368-7315-400a-8311-eca8806f31d5"],
Cell[2760, 90, 1087, 27, 444, "Input",ExpressionUUID->"863bdfdb-6227-4c24-a780-947166430feb"],
Cell[3850, 119, 206, 5, 53, "Text",ExpressionUUID->"c8b8a9da-0de6-445b-929d-7327a24efdf3"],
Cell[CellGroupData[{
Cell[4081, 128, 151, 2, 30, "Input",ExpressionUUID->"47377824-776b-4e38-a9f6-446ef097af73"],
Cell[4235, 132, 2369, 42, 376, "Output",ExpressionUUID->"f7a6cff9-1041-406a-819d-4c5fa137aea6"]
}, Open  ]],
Cell[6619, 177, 165, 3, 53, "Text",ExpressionUUID->"ec19e250-739b-422b-8202-b0fa231caa9e"],
Cell[CellGroupData[{
Cell[6809, 184, 246, 3, 30, "Input",ExpressionUUID->"eceb42ef-f69f-47b1-9cdf-1e0191672987"],
Cell[7058, 189, 12160, 224, 139, "Output",ExpressionUUID->"13c14824-cbe8-4388-9b27-97f04dc2f77f"]
}, Open  ]],
Cell[19233, 416, 364, 10, 76, "Text",ExpressionUUID->"165e2b51-0439-4b6d-84d2-4f7d426b545a"],
Cell[19600, 428, 1770, 44, 750, "Input",ExpressionUUID->"d8233bb1-3ae6-4b89-9ac4-9b16b6e65e86"],
Cell[21373, 474, 277, 6, 53, "Text",ExpressionUUID->"a8a3f3a5-d4d3-4498-a5ef-9205eee5848c"],
Cell[CellGroupData[{
Cell[21675, 484, 165, 2, 30, "Input",ExpressionUUID->"71ff4ec0-2b5c-4bb9-8bf2-666d6444d2ee"],
Cell[21843, 488, 4290, 74, 376, "Output",ExpressionUUID->"6285528d-b4b4-4714-9131-f9ee3dce17ca"]
}, Open  ]],
Cell[26148, 565, 362, 10, 76, "Text",ExpressionUUID->"6f826f99-88ed-49ea-830d-c748cf1817fd"],
Cell[26513, 577, 1570, 38, 642, "Input",ExpressionUUID->"d7d5cc3f-fbfd-4225-848c-417d2417b52a"],
Cell[28086, 617, 277, 6, 76, "Text",ExpressionUUID->"1ef09b45-1bfe-4315-a91f-b003281dd163"],
Cell[CellGroupData[{
Cell[28388, 627, 164, 2, 30, "Input",ExpressionUUID->"60e6a205-9c3d-479a-a076-30198971c8f2"],
Cell[28555, 631, 3537, 63, 399, "Output",ExpressionUUID->"2f7f124c-7f24-4707-ae1e-d48444526181"]
}, Open  ]]
}
]
*)

